@@ -732,7 +732,10 @@ test_that("matrixset 'long' loop works", {
                "vectors must be of the same length")
 
 
-
+  expect_error(apply_column_dfl(student_results, .colname = mean))
+  expect_error(apply_column_dfw(student_results, .colname = mean))
+  expect_error(apply_row_dfl(student_results, .rowname = mean))
+  expect_error(apply_row_dfw(student_results, .rowname = mean))
 
 
 
